@@ -19,7 +19,8 @@
 /* This is the gdm slave process. gdmslave runs the chooser, greeter
  * and the user's session scripts. */
 
-#include <config.h>
+#include "config.h"
+
 #include <unistd.h>
 #include <syslog.h>
 #include <grp.h>
@@ -303,6 +304,7 @@ gdm_error_box_full (GdmDisplay *d, GtkMessageType type, const char *error,
 		    const char *details_label, const char *details_file,
 		    uid_t uid, gid_t gid)
 {
+	GdkDisplay *gdk_display;
 	pid_t pid;
 
 	pid = gdm_fork_extra ();
@@ -359,7 +361,7 @@ gdm_error_box_full (GdmDisplay *d, GtkMessageType type, const char *error,
 					g_string_append (gs, buf);
 					/* cap the lines at 500, that's already
 					   a possibility of 128k of data */
-					if (lines ++ > 500) {
+					if (lines++ > 500) {
 						loc = gdm_locale_to_utf8 (_("\n... File too long to display ...\n"));
 						g_string_append (gs, loc);
 						g_free (loc);
@@ -385,9 +387,7 @@ gdm_error_box_full (GdmDisplay *d, GtkMessageType type, const char *error,
 			details = NULL;
 		}
 
-		setup_dialog (d, "gtk-error-box", -1,
-			      (uid == 0 || uid == gdm_get_gdmuid ()) /* set_gdm_ids */,
-			      uid);
+		setup_dialog (d, "gtk-error-box", -1, TRUE, uid);
 
 		loc = gdm_locale_to_utf8 (error);
 
@@ -441,9 +441,11 @@ gdm_error_box_full (GdmDisplay *d, GtkMessageType type, const char *error,
 
 		gtk_widget_show_now (dlg);
 
+		gdk_display = gdk_display_get_default ();
+
 		if (dlg->window != NULL) {
 			gdk_error_trap_push ();
-			XSetInputFocus (GDK_DISPLAY (),
+			XSetInputFocus (GDK_DISPLAY_XDISPLAY (gdk_display),
 					GDK_WINDOW_XWINDOW (dlg->window),
 					RevertToPointerRoot,
 					CurrentTime);
@@ -455,7 +457,7 @@ gdm_error_box_full (GdmDisplay *d, GtkMessageType type, const char *error,
 
 		gtk_dialog_run (GTK_DIALOG (dlg));
 
-		XSetInputFocus (GDK_DISPLAY (),
+		XSetInputFocus (GDK_DISPLAY_XDISPLAY (gdk_display),
 				PointerRoot,
 				RevertToPointerRoot,
 				CurrentTime);
@@ -507,6 +509,7 @@ gdm_failsafe_question (GdmDisplay *d,
 		       const char *question,
 		       gboolean echo)
 {
+	GdkDisplay *gdk_display;
 	pid_t pid;
 	int p[2];
 
@@ -560,9 +563,11 @@ gdm_failsafe_question (GdmDisplay *d,
 
 		gtk_widget_show_now (dlg);
 
+		gdk_display = gdk_display_get_default ();
+
 		if (dlg->window != NULL) {
 			gdk_error_trap_push ();
-			XSetInputFocus (GDK_DISPLAY (),
+			XSetInputFocus (GDK_DISPLAY_XDISPLAY (gdk_display),
 					GDK_WINDOW_XWINDOW (dlg->window),
 					RevertToPointerRoot,
 					CurrentTime);
@@ -580,7 +585,7 @@ gdm_failsafe_question (GdmDisplay *d,
 
 		gdm_fdprintf (p[1], "%s", ve_sure_string (loc));
 
-		XSetInputFocus (GDK_DISPLAY (),
+		XSetInputFocus (GDK_DISPLAY_XDISPLAY (gdk_display),
 				PointerRoot,
 				RevertToPointerRoot,
 				CurrentTime);
@@ -632,6 +637,7 @@ gboolean
 gdm_failsafe_yesno (GdmDisplay *d,
 		    const char *question)
 {
+	GdkDisplay *gdk_display;
 	pid_t pid;
 	int p[2];
 
@@ -669,9 +675,11 @@ gdm_failsafe_yesno (GdmDisplay *d,
 
 		gtk_widget_show_now (dlg);
 
+		gdk_display = gdk_display_get_default ();
+
 		if (dlg->window != NULL) {
 			gdk_error_trap_push ();
-			XSetInputFocus (GDK_DISPLAY (),
+			XSetInputFocus (GDK_DISPLAY_XDISPLAY (gdk_display),
 					GDK_WINDOW_XWINDOW (dlg->window),
 					RevertToPointerRoot,
 					CurrentTime);
@@ -686,7 +694,7 @@ gdm_failsafe_yesno (GdmDisplay *d,
 		else
 			gdm_fdprintf (p[1], "no\n");
 
-		XSetInputFocus (GDK_DISPLAY (),
+		XSetInputFocus (GDK_DISPLAY_XDISPLAY (gdk_display),
 				PointerRoot,
 				RevertToPointerRoot,
 				CurrentTime);
@@ -741,6 +749,7 @@ gdm_failsafe_ask_buttons (GdmDisplay *d,
 			  const char *question,
 			  char **but)
 {
+	GdkDisplay *gdk_display;
 	pid_t pid;
 	int p[2];
 
@@ -787,9 +796,11 @@ gdm_failsafe_ask_buttons (GdmDisplay *d,
 
 		gtk_widget_show_now (dlg);
 
+		gdk_display = gdk_display_get_default ();
+
 		if (dlg->window != NULL) {
 			gdk_error_trap_push ();
-			XSetInputFocus (GDK_DISPLAY (),
+			XSetInputFocus (GDK_DISPLAY_XDISPLAY (gdk_display),
 					GDK_WINDOW_XWINDOW (dlg->window),
 					RevertToPointerRoot,
 					CurrentTime);
@@ -802,7 +813,7 @@ gdm_failsafe_ask_buttons (GdmDisplay *d,
 		i = gtk_dialog_run (GTK_DIALOG (dlg));
 		gdm_fdprintf (p[1], "%d\n", i);
 
-		XSetInputFocus (GDK_DISPLAY (),
+		XSetInputFocus (GDK_DISPLAY_XDISPLAY (gdk_display),
 				PointerRoot,
 				RevertToPointerRoot,
 				CurrentTime);
