@@ -79,8 +79,6 @@ GreeterItemInfo *welcome_string_info = NULL;
 extern gboolean session_dir_whacked_out;
 extern gboolean require_quarter;
 extern gint gdm_timed_delay;
-extern GtkButton *gtk_ok_button;
-extern GtkButton *gtk_start_again_button;
 
 gboolean greeter_probably_login_prompt = FALSE;
 
@@ -192,16 +190,9 @@ process_operation (guchar       op_code,
 					gdm_config_get_string (GDM_KEY_SOUND_ON_LOGIN_FILE),
 					gdm_config_get_bool (GDM_KEY_SOUND_ON_LOGIN));
 		greeter_probably_login_prompt = TRUE;
-		if (gtk_start_again_button != NULL)
-	                gtk_widget_set_sensitive (gtk_start_again_button, FALSE);
 	} else {
 		greeter_probably_login_prompt = FALSE;
-		if (gtk_start_again_button != NULL)
-                	gtk_widget_set_sensitive (gtk_start_again_button, TRUE);
 	}
-	if (gtk_ok_button != NULL)
-                gtk_widget_set_sensitive (gtk_ok_button, FALSE);
-
 	greeter_ignore_buttons (FALSE);
 
 	greeter_item_pam_prompt (tmp, PW_ENTRY_SIZE, TRUE);
@@ -216,16 +207,8 @@ process_operation (guchar       op_code,
     case GDM_NOECHO:
 	tmp = ve_locale_to_utf8 (args);
 
-	if (tmp != NULL && strcmp (tmp, _("Password:")) == 0) {
-		if (gtk_start_again_button != NULL)
-                	gtk_widget_set_sensitive (gtk_start_again_button, TRUE);
+	if (tmp != NULL && strcmp (tmp, _("Password:")) == 0)
 		greeter_probably_login_prompt = FALSE;
-	} else {
-		if (gtk_start_again_button != NULL)
-                	gtk_widget_set_sensitive (gtk_start_again_button, FALSE);
-	}
-	if (gtk_ok_button != NULL)
-                gtk_widget_set_sensitive (gtk_ok_button, FALSE);
 
 	greeter_ignore_buttons (FALSE);
 	greeter_item_pam_prompt (tmp, PW_ENTRY_SIZE, FALSE);
@@ -323,11 +306,6 @@ process_operation (guchar       op_code,
 
     case GDM_RESETOK:
 
-	if (gtk_ok_button != NULL)
-                gtk_widget_set_sensitive (gtk_ok_button, FALSE);
-	if (gtk_start_again_button != NULL)
-                gtk_widget_set_sensitive (gtk_start_again_button, FALSE);
-
 	conversation_info = greeter_lookup_id ("pam-conversation");
 	
 	if (conversation_info)
@@ -795,6 +773,7 @@ gdm_read_config (void)
 	gdm_config_get_bool   (GDM_KEY_SOUND_ON_LOGIN);
 	gdm_config_get_bool   (GDM_KEY_DEFAULT_WELCOME);
 	gdm_config_get_bool   (GDM_KEY_DEFAULT_REMOTE_WELCOME);
+	gdm_config_get_bool   (GDM_KEY_ADD_GTK_MODULES);
 
 	/* Keys not to include in reread_config */
 	gdm_config_get_string (GDM_KEY_SESSION_DESKTOP_DIR);
@@ -854,7 +833,8 @@ greeter_reread_config (int sig, gpointer data)
 	    gdm_config_reload_bool   (GDM_KEY_GRAPHICAL_THEME_RAND) ||
 	    gdm_config_reload_bool   (GDM_KEY_SHOW_LAST_SESSION) ||
 	    gdm_config_reload_bool   (GDM_KEY_ALLOW_ROOT) ||
-	    gdm_config_reload_bool   (GDM_KEY_ALLOW_REMOTE_ROOT)) {
+	    gdm_config_reload_bool   (GDM_KEY_ALLOW_REMOTE_ROOT) ||
+	    gdm_config_reload_bool   (GDM_KEY_ADD_GTK_MODULES)) {
 
 		/* Set busy cursor */
 		gdm_common_setup_cursor (GDK_WATCH);
@@ -1064,9 +1044,18 @@ main (int argc, char *argv[])
   else
 	   GDM_IS_LOCAL = TRUE;
 
+  /*
+   * gdm_common_atspi_launch () needs gdk initialized.
+   * We cannot start gtk before the registry is running 
+   * because the atk-bridge will crash.
+   */
+  gdk_init (&argc, &argv);
+  if (! DOING_GDM_DEVELOPMENT) {
+     gdm_common_atspi_launch ();
+  }
+
   gtk_init (&argc, &argv);
 
-  /* Should be a watch already, but anyway */
   gdm_common_setup_cursor (GDK_WATCH);
 
   /* Read all configuration at once, so the values get cached */
@@ -1099,7 +1088,6 @@ main (int argc, char *argv[])
   }
   gdm_common_setup_background_color (bg_color);
   greeter_session_init ();
-  greeter_language_initialize_model ();
 
   ve_signal_add (SIGHUP, greeter_reread_config, NULL);
 
@@ -1355,7 +1343,6 @@ main (int argc, char *argv[])
 
   greeter_item_ulist_unset_selected_user ();
   greeter_item_ulist_enable ();
-  greeter_item_ulist_check_show_userlist ();
 
   /* can it ever happen that it'd be NULL here ??? */
   if G_UNLIKELY (window->window != NULL)
@@ -1464,7 +1451,7 @@ main (int argc, char *argv[])
   gdm_wm_restore_wm_order ();
 
   gdm_wm_show_info_msg_dialog (gdm_config_get_string (GDM_KEY_INFO_MSG_FILE),
-     gdm_config_get_string (GDM_KEY_INFO_MSG_FONT));
+	gdm_config_get_string (GDM_KEY_INFO_MSG_FONT));
 
   gdm_common_setup_cursor (GDK_LEFT_PTR);
   gdm_wm_center_cursor ();
