@@ -856,37 +856,6 @@ parse_state_file_pixmap (xmlNodePtr node,
 	
       xmlFree (prop);
     }
-
-    {
-      int i = 1;
-      char *altfile_prop_name = g_strdup_printf ("altfile%d", i);
-
-      prop = xmlGetProp (node,(const xmlChar *) altfile_prop_name);
-      while (prop)
-        {
-          char *filename = NULL;
-          if (g_path_is_absolute ((char *) prop))
-            filename = g_strdup ((char *) prop);
-          else
-            filename = g_build_filename (file_search_path,
-                                         (char *) prop,
-                                         NULL);
-
-          if (g_file_test (filename, G_FILE_TEST_EXISTS))
-            {
-              if (info->data.pixmap.files[state])
-                g_free (info->data.pixmap.files[state]);
-              info->data.pixmap.files[state] = filename;
-            }
-          xmlFree (prop);
-          g_free (altfile_prop_name);
-
-          i++;
-          altfile_prop_name = g_strdup_printf ("altfile%d", i);
-          prop = xmlGetProp (node,(const xmlChar *) altfile_prop_name);
-        }
-      g_free (altfile_prop_name);
-    }
   
   prop = xmlGetProp (node,(const xmlChar *) "tint");
   if (prop)
@@ -1488,22 +1457,6 @@ parse_list (xmlNodePtr        node,
 	     GError         **error)
 {
   xmlNodePtr child;
-  xmlChar *prop;
-
-  info->data.list.combo_type = FALSE;
-  prop = xmlGetProp (node,(const xmlChar *) "combo");
-  if (prop)
-    {
-      if (strcmp ((char *) prop, "true") == 0)
-	{
-	  info->data.list.combo_type = TRUE;
-	}
-      else if (strcmp ((char *) prop, "false") == 0)
-	{
-	  info->data.list.combo_type = FALSE;
-	}
-      xmlFree (prop);
-    }
 
   child = node->children;
   while (child)
@@ -1541,28 +1494,15 @@ parse_list (xmlNodePtr        node,
       child = child->next;
     }
 
-  if ((strcmp (info->id, "userlist") == 0) && (info->data.list.combo_type == TRUE)) {
+  if (info->data.list.items != NULL) {
+    if G_UNLIKELY (strcmp (info->id, "userlist") == 0) {
       g_set_error (error,
 		   GREETER_PARSER_ERROR,
 		   GREETER_PARSER_ERROR_BAD_SPEC,
-		   "userlist doest not support combo style");
-      return FALSE;
-  } else if (info->data.list.items != NULL) {
-
-    if G_UNLIKELY (strcmp (info->id, "userlist") == 0 ||
-                   strcmp (info->id, "session")  == 0 ||
-                   strcmp (info->id, "language") == 0) {
-      g_set_error (error,
-		   GREETER_PARSER_ERROR,
-		   GREETER_PARSER_ERROR_BAD_SPEC,
-		   "List of id userlist, session, and language cannot have custom list items");
+		   "List of id userlist cannot have custom list items");
       return FALSE;
     }
     custom_items = g_list_append (custom_items, info);
-
-  } else if (strcmp (info->id, "session") == 0 ||
-             strcmp (info->id, "language") == 0) {
-    custom_items = g_list_append (custom_items, info);
   }
 
   return TRUE;
@@ -1641,7 +1581,7 @@ parse_items (xmlNodePtr  node,
 			     "Found tag %s when looking for item", child->name);
 		return FALSE;
 	      }
-	    
+
 	    type = xmlGetProp (child, (const xmlChar *) "type");
 	    if G_UNLIKELY (!type)
 	      {
@@ -1677,7 +1617,7 @@ parse_items (xmlNodePtr  node,
 	      }
 
 	    xmlFree (type);
-	    
+
 	    info = greeter_item_info_new (parent, item_type);
 	    
 	    parse_id (child, info);
